@@ -1,18 +1,12 @@
 ## File Name: tam_fa_reliability_nonlinearSEM.R
-## File Version: 9.10
+## File Version: 9.12
 
 
-#********************************************************************
-# Function calculates reliability from nonlinear SEM
+#---- Function calculates reliability from nonlinear SEM
 tam_fa_reliability_nonlinearSEM <- function( facloadings, thresh, cor.factors=NULL )
 {
-    # INPUT:
-    # loadings      ... matrix of factor loadings
-    # thresh        ... vector of thresholds
-    # cor.factors   ... correlation matrix of factors
-    #.............................................
-    facloadings <- as.matrix( facloadings )
-    NF <- ncol(facloadings ) # number of factor facloadings
+    facloadings <- as.matrix(facloadings)
+    NF <- ncol(facloadings) # number of factor facloadings
     # correlation matrix
     if ( is.null(cor.factors)){
         cor.factors <- matrix( 0, nrow=NF, ncol=NF )
@@ -21,9 +15,9 @@ tam_fa_reliability_nonlinearSEM <- function( facloadings, thresh, cor.factors=NU
     # number of items
     I <- nrow(facloadings)
     # transform thresholds
-    pthresh <- stats::pnorm( thresh )
+    pthresh <- stats::pnorm(thresh)
     # create matrix of multiplied facloadings (expected correlation)
-    rho.exp <- matrix( 0, I, I )
+    rho.exp <- matrix( 0, nrow=I, ncol=I )
     colnames(rho.exp) <- rownames(rho.exp) <- rownames(facloadings)
     # reliability matrix
     rel.matrix2 <- rel.matrix <- rho.exp
@@ -34,13 +28,13 @@ tam_fa_reliability_nonlinearSEM <- function( facloadings, thresh, cor.factors=NU
             rho.exp[ii2,ii1] <- rho.exp[ii1,ii2]
             r1 <- rho.exp[ii1,ii2]
             rel.matrix2[ii1,ii2] <- rel.matrix[ii1,ii2] <- mvtnorm::pmvnorm( c(-Inf,-Inf), pthresh[c(ii1,ii2)],
-                                         corr=matrix( c( 1, r1, r1, 1),2,2 ) ) -
+                                        corr=matrix( c( 1, r1, r1, 1),2,2 ) ) -
                                             stats::pnorm( pthresh[ii1] ) * stats::pnorm( pthresh[ii2] )
             rel.matrix2[ii2,ii1] <- rel.matrix[ii2,ii1] <- rel.matrix[ii1,ii2]
             if (ii1==ii2){
                 r1 <- 1
                 rel.matrix2[ii1,ii2] <- mvtnorm::pmvnorm( c(-Inf,-Inf), pthresh[c(ii1,ii2)],
-                                            corr=matrix( c( 1, r1, r1, 1),2,2 ) ) -
+                                    corr=matrix( c( 1, r1, r1, 1),2,2 ) ) -
                                                 stats::pnorm( pthresh[ii1] ) * stats::pnorm( pthresh[ii2] )
                 rel.matrix2[ii2,ii1] <- rel.matrix2[ii1,ii2]
             }
@@ -49,9 +43,9 @@ tam_fa_reliability_nonlinearSEM <- function( facloadings, thresh, cor.factors=NU
     # calculation of reliability
     omega.rel <- sum( rel.matrix ) / sum( rel.matrix2 )
     # output
-    res <- list( "omega.rel"=omega.rel, "NF"=NF, "cor.factors"=cor.factors,
-                    "pthresh"=pthresh, "rho.exp"=rho.exp, "rel.matrix"=rel.matrix,
-                    "rel.matrix2"=rel.matrix2)
+    res <- list( omega.rel=omega.rel, NF=NF, cor.factors=cor.factors,
+                    pthresh=pthresh, rho.exp=rho.exp, rel.matrix=rel.matrix,
+                    rel.matrix2=rel.matrix2)
     return(res)
 }
-#********************************************************************
+
