@@ -1,5 +1,5 @@
 ## File Name: tam_summary_print_ic.R
-## File Version: 0.24
+## File Version: 0.26
 
 tam_summary_print_ic <- function( object, digits_ic=0, digits_values=2, bayes_crit=FALSE )
 {
@@ -21,10 +21,10 @@ tam_summary_print_ic <- function( object, digits_ic=0, digits_values=2, bayes_cr
         if (bayes_crit){
             #--- information criteria based on Bayesian inference
             cat("Criteria based on Fully Bayesian Inference\n")
-            cat( "\nDbar=", round( object$ic$Dbar, digits_values )  )
-            cat( "\nDhat=", round( object$ic$Dhat, digits_values )  )
-            cat( "\npD=", round( object$ic$pD, digits_values )  )
-            cat( "\nDIC=", round( object$ic$DIC, digits_ic )," | penalty=",
+            cat( "\nDbar", "=", round( object$ic$Dbar, digits_values )  )
+            cat( "\nDhat", "=", round( object$ic$Dhat, digits_values )  )
+            cat( "\npD", "=", round( object$ic$pD, digits_values )  )
+            cat( "\nDIC", "=", round( object$ic$DIC, digits_ic )," | penalty=",
                             round( 2*object$ic$pD, digits_values ) )
             cat("   | DIC=Dhat + 2*pD\n\n" )
         }
